@@ -2,7 +2,7 @@
 #ifdef LAFEREVISION
 char *LafeRevision=LAFEREVISION;
 #else
-char *LafeRevision="$Revision: 0.38 $";
+char *LafeRevision="$Revision: 1.2 $";
 #endif 
 
 /* Latency Free Empire
@@ -19,11 +19,8 @@ char *LafeRevision="$Revision: 0.38 $";
    moment required.  If you want lafe without readline, use emp_client
    instead.
 
-   -dld@debian.org (aka harmless) */
+   -harmless@empire.net */
 
-/*  Copyright 1998,1999,2000 Drake Diedrich
-    Distributed under the GNU General Public License.
-    See file COPYING for details. */
 
 
 #include <stdio.h>
@@ -59,8 +56,8 @@ char *LafeRevision="$Revision: 0.38 $";
 
 
 /* some defaults in case nothing is specified.  Change as you wish. */
-#define DEFPORT "6789"
-#define DEFHOST "www.empire.cx"
+#define DEFPORT "6667"
+#define DEFHOST "149.84.128.9"
 #define DEFCOUNTRY "visitor"
 #define DEFPASSWORD "visitor"
 
@@ -91,15 +88,17 @@ extern void parse_command(char *);
 
 /* the length of the prompt.  This plus rl_point is how far we have to
    go back to the beginning of the line. */
-extern int rl_visible_prompt_length;
+/* extern int rl_visible_prompt_length; */
 
 /*  I'm cheating by using these.  */
+/*
 extern int _rl_horizontal_scroll_mode;
 extern int _rl_vis_botlin, _rl_last_v_pos, _rl_last_c_pos;
+*/
 
 /* pointer to the readline prompt.  This can change in the middle of
  * readline() if a prompt arrives in the middle of typing. */
-extern char *rl_prompt,*rl_display_prompt;
+/* extern char *rl_prompt,*rl_display_prompt; */
 
 
 
@@ -181,14 +180,18 @@ void clear_readline() {
   if (tc_ch) {
     /* extra 0 added to tparm() so tgoto() can be used interchangeably */
     tputs(tparm(tc_ch,0,0),1,putcharf);
-  } else if (tc_LE) {
+#if 0  
+  }
+   else if (tc_LE) {
     tputs(tparm(tc_LE,_rl_last_c_pos,0),1,putcharf);
+#endif
   } else if (tc_rc) {
     tputs(tc_rc,1,putcharf);
   } else {
     putcharf('\r');
   }
 
+#if 0
   if (_rl_last_v_pos>0) {
     if (tc_UP) {
       tputs(tparm(tc_UP,_rl_last_v_pos,0),1,putcharf);
@@ -196,6 +199,7 @@ void clear_readline() {
       /* couldn't reach beginning, the display will look weird */
     }
   }
+#endif
 
   if (tc_cd) {
     tputs(tc_cd,1,putcharf);
@@ -217,6 +221,7 @@ void save_readline() {
 
 
 void quit() {
+  rl_cleanup_after_signal();
   exit(0);
 }
 
@@ -346,9 +351,12 @@ void process_line(char *buffer,int len) {
       }
 
       /* cheated a bit here again.. this isn't supposed to be allowed */
-      rl_display_prompt=rl_prompt=prompt;
-	
+      /* rl_display_prompt=rl_prompt=prompt; */
+      rl_set_prompt(prompt);
+/*      rl_redisplay(); */
+#if 0	
       rl_visible_prompt_length = rl_expand_prompt(rl_prompt);
+#endif
 
     } else {
       teles=0;
@@ -380,11 +388,15 @@ void process_line(char *buffer,int len) {
     prompt[len-3]=' ';
     prompt[len-2]=0;
     if (!commands) {
-      rl_display_prompt=rl_prompt=prompt;
+/*      rl_display_prompt=rl_prompt=prompt; */
+	rl_set_prompt(prompt);
     } else {
-      rl_display_prompt=rl_prompt=": ";
+/*      rl_display_prompt=rl_prompt=": "; */
+	rl_set_prompt(": ");
     }
+#if 0
     rl_visible_prompt_length = rl_expand_prompt(rl_prompt);
+#endif
     break;
 
   case '6':
@@ -418,11 +430,15 @@ void process_line(char *buffer,int len) {
 
     /* cheated a bit here again.. this isn't supposed to be allowed */
     if (!commands) {
-      rl_display_prompt=rl_prompt=prompt;
+      rl_set_prompt(prompt);
+/*      rl_redisplay(); */
+      /* rl_display_prompt=rl_prompt=prompt; */
     } else {
-      rl_display_prompt=rl_prompt=": ";
+      /* rl_display_prompt=rl_prompt=": "; */
+      rl_set_prompt(": ");
+      rl_redisplay();
     }
-    rl_visible_prompt_length = rl_expand_prompt(rl_prompt);
+/*    rl_visible<_prompt_length = rl_expand_prompt(rl_prompt); */
 
     break;
 
@@ -526,6 +542,7 @@ void event_hook() {
   if (i<=0) {
     if (interrupts>1) {
       printf("Exitting on multiple interrupts\n");
+      rl_cleanup_after_signal();
       exit(-1);
     } else if (interrupts) {
       write(s,"aborted\n",8);
@@ -591,6 +608,7 @@ void waitsync(char *dummy) {
     if (i<=0) {
       if (interrupts>1) {
 	printf("Exitting on multiple interrupts\n");
+        rl_cleanup_after_signal();
 	exit(-1);
       } else if (interrupts) {
 	write(s,"aborted\n",8);
@@ -658,7 +676,7 @@ int empconnect(char *host,int port,char *user,char *country,char *pass) {
     return -1;
   }
   sin.sin_family = AF_INET;
-  if (connect(s, &sin, sizeof(sin)) < 0) {
+  if (connect(s, (struct sockaddr*)&sin, sizeof(sin)) < 0) {
     perror("connect");
     return -1;
   }
